@@ -16,7 +16,17 @@ class classproperty(object):
         return self.fget(owner_cls)
 
 
-class meta:
+# https://stackoverflow.com/questions/8955754/can-i-define-a-repr-for-a-class-rather-than-an-instance
+class MetaRepr(type):
+    def __repr__(cls):
+        return (
+            "Metadata object with .live and .store metadata fields:\n"
+            f"  .store: {cls.store}\n"
+            f"  .live: {cls.live}"
+        )
+
+
+class meta(metaclass=MetaRepr):
     """Access `meta.store` and `meta.live`.
 
     - `meta.store` - nbproject metadata of the ipynb file, see
@@ -55,7 +65,10 @@ class meta:
         cls._env = env
         cls._time_run = _time_run
 
-        nb_meta = read_notebook(cls._filepath).metadata
+        if cls._filepath is not None:
+            nb_meta = read_notebook(cls._filepath).metadata
+        else:
+            nb_meta = None
 
         if nb_meta is not None and "nbproject" in nb_meta:
             meta_container = MetaContainer(**nb_meta["nbproject"])
@@ -86,10 +99,3 @@ class meta:
         if cls._env is None:
             cls._init_meta()
         return cls._env
-
-    def __repr__(self):
-        return (
-            "Metadata object with .live and .store metadata fields:\n"
-            f"  .store: {self.store}\n"
-            f"  .live: {self.live}"
-        )
